@@ -1,10 +1,4 @@
 package Test::MTA::Exim4;
-BEGIN {
-  $Test::MTA::Exim4::VERSION = '0.04';
-}
-BEGIN {
-  $Test::MTA::Exim4::AUTHORITY = 'cpan:NIGELM';
-}
 
 use warnings;
 use strict;
@@ -13,6 +7,9 @@ use base qw(Class::Accessor::Fast);
 use IPC::Cmd qw[can_run run];
 use Test::Builder;
 
+our $VERSION = '0.05'; # VERSION
+our $AUTHORITY = 'cpan:NIGELM'; # AUTHORITY
+
 __PACKAGE__->mk_accessors(qw[ debug]);
 __PACKAGE__->mk_ro_accessors(qw[exim_path config_file test timeout]);
 
@@ -31,23 +28,22 @@ sub new {
     bless( $self, $class );
 
     # set some defaults if not already in place
-    $self->{exim_path} ||=
-         $ENV{DEFAULT_EXIM_PATH}
-      || can_run('exim4')
-      || can_run('exim')
-      || '/usr/sbin/exim';
+    $self->{exim_path}
+        ||= $ENV{DEFAULT_EXIM_PATH}
+        || can_run('exim4')
+        || can_run('exim')
+        || '/usr/sbin/exim';
     $self->{config_file} ||= $ENV{DEFAULT_EXIM_CONFIG_FILE};
     $self->{test}        ||= Test::Builder->new;
     $self->{timeout}     ||= 5;
 
     # check that underlying IPC::Cmd has sufficient capabilities
     IPC::Cmd->can_capture_buffer
-      || $self->_croak(
-        'IPC::Cmd cannot capture buffers on this system - testing will fail');
+        || $self->_croak('IPC::Cmd cannot capture buffers on this system - testing will fail');
 
     # check that exim is there and runnable
     can_run( $self->{exim_path} )
-      || $self->_croak('No runnable exim binary found');
+        || $self->_croak('No runnable exim binary found');
 
     # reset internal state
     $self->reset;
@@ -76,14 +72,8 @@ sub config_ok {
     $self->_run_exim_bv;
 
     # pad the msg if not specified
-    $msg ||= sprintf(
-        'config %s is valid',
-        (
-                 $self->{_state}{exim_config_file}
-              || $self->{config_file}
-              || '(unknown)'
-        )
-    );
+    $msg ||= sprintf( 'config %s is valid',
+        ( $self->{_state}{exim_config_file} || $self->{config_file} || '(unknown)' ) );
 
     $self->test->ok( $self->{_state}{config}{ok}, $msg ) || $self->_diag;
 }
@@ -113,6 +103,125 @@ sub exim_build {
 # ------------------------------------------------------------------------
 
 
+sub has_option {
+    my $self   = shift;
+    my $option = shift;
+    my $msg    = shift;
+
+    $self->_run_exim_bv;
+    $self->_croak('Invalid exim config') unless ( $self->{_state}{config}{ok} );
+    $self->_run_exim_bp;
+
+    # pad the msg if not specified
+    $msg ||= sprintf( 'Checking for existence of %s option', $option );
+
+    $self->test->ok( exists $self->{_state}{option}{$option}, $msg )
+        || $self->_diag;
+}
+
+# ------------------------------------------------------------------------
+
+
+sub has_not_option {
+    my $self   = shift;
+    my $option = shift;
+    my $msg    = shift;
+
+    $self->_run_exim_bv;
+    $self->_croak('Invalid exim config') unless ( $self->{_state}{config}{ok} );
+    $self->_run_exim_bp;
+
+    # pad the msg if not specified
+    $msg ||= sprintf( 'Checking for lack of existence of %s option', $option );
+
+    $self->test->ok( !exists $self->{_state}{option}{$option}, $msg )
+        || $self->_diag;
+}
+
+# ------------------------------------------------------------------------
+
+
+sub option_is {
+    my $self   = shift;
+    my $option = shift;
+    my $value  = shift;
+    my $msg    = shift;
+
+    $self->_run_exim_bv;
+    $self->_croak('Invalid exim config') unless ( $self->{_state}{config}{ok} );
+    $self->_run_exim_bp;
+
+    # pad the msg if not specified
+    $msg ||= sprintf( 'Checking for %s option', $option );
+
+    $self->test->is_eq( $self->{_state}{option}{$option}, $value, $msg )
+        || $self->_diag;
+}
+
+# ------------------------------------------------------------------------
+
+
+sub option_is_true {
+    my $self   = shift;
+    my $option = shift;
+    my $msg    = shift;
+
+    $self->_run_exim_bv;
+    $self->_croak('Invalid exim config') unless ( $self->{_state}{config}{ok} );
+    $self->_run_exim_bp;
+
+    # pad the msg if not specified
+    $msg ||= sprintf( 'Checking for %s option', $option );
+
+    my $value = $option =~ s/^no_// ? undef : 1;
+    $self->test->is_eq( $self->{_state}{option}{$option}, $value, $msg )
+        || $self->_diag;
+}
+
+# ------------------------------------------------------------------------
+
+
+sub option_is_false {
+    my $self   = shift;
+    my $option = shift;
+    my $msg    = shift;
+
+    $self->_run_exim_bv;
+    $self->_croak('Invalid exim config') unless ( $self->{_state}{config}{ok} );
+    $self->_run_exim_bp;
+
+    # pad the msg if not specified
+    $msg ||= sprintf( 'Checking for %s option', $option );
+
+    my $value = $option =~ s/^no_// ? 1 : undef;
+    $self->test->is_eq( $self->{_state}{option}{$option}, $value, $msg )
+        || $self->_diag;
+}
+
+# ------------------------------------------------------------------------
+
+
+sub expansion_is {
+    my $self   = shift;
+    my $string = shift;
+    my $expect = shift;
+    my $msg    = shift;
+
+    $self->_run_exim_bv;
+    $self->_croak('Invalid exim config') unless ( $self->{_state}{config}{ok} );
+
+    # pad the msg if not specified
+    $msg ||= sprintf( "Checking expansion of '%s'", $string );
+
+    my $got = $self->_run_exim_be($string);
+    chomp $got;
+    $self->test->is_eq( $got, $expect, $msg )
+        || $self->_diag;
+}
+
+# ------------------------------------------------------------------------
+
+
 sub has_capability {
     my $self = shift;
     my $type = shift;
@@ -120,21 +229,15 @@ sub has_capability {
     my $msg  = shift;
 
     $self->_run_exim_bv;
-    $self->_croak('Invalid exim config') unless ( $self->{_state}{config}{ok} );
+    $self->_croak('Invalid exim config')                  unless ( $self->{_state}{config}{ok} );
     $self->_croak('Capability requires a type')           unless ($type);
     $self->_croak('Capability requires a thing to check') unless ($what);
 
     # pad the msg if not specified
     $msg ||= sprintf( 'Checking for %s/%s capability', $type, $what );
 
-    $self->test->ok(
-        (
-                 $self->{_state}{config}{$type}
-              && $self->{_state}{config}{$type}{$what}
-        ),
-        $msg
-      )
-      || $self->_diag;
+    $self->test->ok( ( $self->{_state}{config}{$type} && $self->{_state}{config}{$type}{$what} ), $msg )
+        || $self->_diag;
 }
 
 # ------------------------------------------------------------------------
@@ -147,21 +250,15 @@ sub has_not_capability {
     my $msg  = shift;
 
     $self->_run_exim_bv;
-    $self->_croak('Invalid exim config') unless ( $self->{_state}{config}{ok} );
+    $self->_croak('Invalid exim config')                  unless ( $self->{_state}{config}{ok} );
     $self->_croak('Capability requires a type')           unless ($type);
     $self->_croak('Capability requires a thing to check') unless ($what);
 
     # pad the msg if not specified
     $msg ||= sprintf( 'Checking for lack of %s/%s capability', $type, $what );
 
-    $self->test->ok(
-        (
-            $self->{_state}{config}{$type}
-              && !$self->{_state}{config}{$type}{$what}
-        ),
-        $msg
-      )
-      || $self->_diag;
+    $self->test->ok( ( $self->{_state}{config}{$type} && !$self->{_state}{config}{$type}{$what} ), $msg )
+        || $self->_diag;
 }
 
 # ------------------------------------------------------------------------
@@ -182,7 +279,7 @@ sub routes_ok {
 
     # OK if there are no undeliverables and there are deliverables
     $self->test->ok( ( $res->{deliverable} && !$res->{undeliverable} ), $msg )
-      || $self->_diag;
+        || $self->_diag;
 }
 
 # ------------------------------------------------------------------------
@@ -200,7 +297,7 @@ sub routes_as_ok {
     # if target is a hash, wrap it in an array
     $target = [$target] if ( ref($target) eq 'HASH' );
     $self->_croak('target should be an arrayref')
-      unless ( ref($target) eq 'ARRAY' );
+        unless ( ref($target) eq 'ARRAY' );
 
     # run the check
     my $res = $self->_run_exim_bt($addr);
@@ -210,7 +307,7 @@ sub routes_as_ok {
 
     # check we get the right number of things back
     my $count_ok =
-      ( scalar( keys %{ $res->{addresses} } ) == scalar( @{$target} ) );
+        ( scalar( keys %{ $res->{addresses} } ) == scalar( @{$target} ) );
     my $count         = scalar( @{$target} );
     my $addr_count_ok = 0;
     my $addresses     = { %{ $res->{addresses} } };    #copy address info
@@ -219,14 +316,12 @@ sub routes_as_ok {
     if ($count_ok) {
         foreach my $targetspec ( @{$target} ) {
             $self->_croak('target spec should be hashref')
-              unless ( ref($targetspec) eq 'HASH' );
+                unless ( ref($targetspec) eq 'HASH' );
             foreach my $addr ( keys %{$addresses} ) {
                 my $thisone = 1;
                 foreach my $key ( keys %{$targetspec} ) {
                     unless ( exists( $addresses->{$addr}{$key} )
-                        && ( $addresses->{$addr}{$key} eq $targetspec->{$key} )
-                      )
-                    {
+                        && ( $addresses->{$addr}{$key} eq $targetspec->{$key} ) ) {
                         $thisone = 0;
                         last;
                     }
@@ -241,7 +336,7 @@ sub routes_as_ok {
 
     # return test status
     $self->test->ok( ( $count_ok && ( $addr_count_ok == $count ) ), $msg )
-      || $self->_diag;
+        || $self->_diag;
 }
 
 # ------------------------------------------------------------------------
@@ -261,13 +356,8 @@ sub discards_ok {
     $msg ||= sprintf( 'Discard for %s', $addr );
 
     # OK if there is a total of one address and it was discarded
-    $self->test->ok(
-        (
-                 ( $res->{total} == 1 )
-              && ( values %{ $res->{addresses} } )[0]->{discarded}
-        ),
-        $msg
-    ) || $self->_diag;
+    $self->test->ok( ( ( $res->{total} == 1 ) && ( values %{ $res->{addresses} } )[0]->{discarded} ), $msg )
+        || $self->_diag;
 }
 
 # ------------------------------------------------------------------------
@@ -288,7 +378,7 @@ sub undeliverable_ok {
 
     # OK if there are no deliverables and there are undeliverables
     $self->test->ok( ( $res->{undeliverable} && !$res->{deliverable} ), $msg )
-      || $self->_diag;
+        || $self->_diag;
 }
 
 # ------------------------------------------------------------------------
@@ -303,7 +393,7 @@ sub _run_exim_command {
 
     # we always put the config file as the first argument if we have one
     unshift @args, ( '-C' . $self->{config_file} )
-      if ( $self->{config_file} );
+        if ( $self->{config_file} );
 
     # run command
     my ( $success, $error_code, $full_buf, $stdout_buf, $stderr_buf ) = run(
@@ -338,8 +428,7 @@ sub _run_exim_bv {
     return if ( $self->{_state}{checked}++ );
 
     # run command
-    my ( $success, undef, undef, $stdout_buf,undef ) =
-      $self->_run_exim_command('-bV');
+    my ( $success, undef, undef, $stdout_buf, undef ) = $self->_run_exim_command('-bV');
 
     # parse things out if command worked
     if ($success) {
@@ -364,13 +453,12 @@ sub _run_exim_bv {
                     (.*)                        # and the rest of the line in $2
                     $
                  }ix
-              )
-            {
+                ) {
                 my $type = lc($1);
                 my $res  = lc($2);
                 $type =~ tr/a-z/_/cs;
-                $type =~ s/s$//;             # strip trailing s
-                $res  =~ tr|a-z0-9_ /||cd;
+                $type =~ s/s$//;    # strip trailing s
+                $res =~ tr|a-z0-9_ /||cd;
                 $self->{_state}{config}{$type}{$_} = 1 foreach ( split( /[\s\/]/, $res ) );
             }
             elsif (/Configuration file is (.*)/) {
@@ -381,7 +469,7 @@ sub _run_exim_bv {
         # we do sanity checks here - currently croak on these, which might
         # be too drastic!
         $self->_croak('No exim version number found')
-          unless ( $self->{_state}{exim_version} );
+            unless ( $self->{_state}{exim_version} );
     }
     else {
         $self->{_state}{config}{ok} = 0;
@@ -391,6 +479,50 @@ sub _run_exim_bv {
 # ------------------------------------------------------------------------
 
 
+sub _run_exim_bp {
+    my $self = shift;
+
+    # we only want to run this once per session
+    return if ( exists $self->{_state}{option} );
+
+    # initialize the option hash, because if we don't get anything parseable
+    # back the first time it probably won't succeed subsequently
+    $self->{_state}{option} = {};
+
+    # run command
+    my ( $success, undef, undef, $stdout_buf, undef ) = $self->_run_exim_command('-bP');
+
+    # parse things out if command worked
+    if ($success) {
+        foreach ( @{$stdout_buf} ) {
+            chomp;
+            if (/^(no_)?(\w+)(?: = (.*))?$/) {
+                my ( $negate, $option, $value ) = ( $1, $2, $3 );
+                $self->{_state}{option}{$option} =
+                    $negate ? undef : defined $value ? $value : 1;
+            }
+        }
+    }
+}
+
+# ------------------------------------------------------------------------
+
+
+sub _run_exim_be {
+    my $self   = shift;
+    my $string = shift;
+
+    # run command
+    my ( $success, undef, undef, $stdout_buf, undef ) = $self->_run_exim_command( '-be', $string );
+
+    # parse things out if command worked
+
+    return $success && join( "\n", @$stdout_buf, '' );
+}
+
+# ------------------------------------------------------------------------
+
+
 sub _run_exim_bt {
     my $self    = shift;
     my $address = shift;
@@ -399,15 +531,14 @@ sub _run_exim_bt {
     # check for sanity... make sure we have a valid binary + config
     $self->_run_exim_bv unless ( $self->{_state}{config}{ok} );
     $self->_croak('No exim version number found')
-      unless ( $self->{_state}{config}{ok} );
+        unless ( $self->{_state}{config}{ok} );
 
     my @options = ('-bt');
     push( @options, '-f', $sender ) if ( defined($sender) );
     push( @options, '--', $address );
 
     # run command - use a -- divider to prevent funkiness in the address
-    my ( $success, undef, undef, $stdout_buf, undef ) =
-      $self->_run_exim_command(@options);
+    my ( $success, undef, undef, $stdout_buf, undef ) = $self->_run_exim_command(@options);
 
     # as exim uses the exit value to signify how well things worked, and
     # IPC::Cmd obscures this somewhat, we are just going to ignore it!
@@ -488,11 +619,10 @@ sub _diag {
             $self->{_state}{last_error},
             join(
                 ' ',
-                @{
-                    ( ref( $self->{_state}{last_output} ) eq 'ARRAY' )
+                @{  ( ref( $self->{_state}{last_output} ) eq 'ARRAY' )
                     ? $self->{_state}{last_output}
                     : [ $self->{_state}{last_output} ]
-                  }
+                }
             )
         )
     );
@@ -504,12 +634,14 @@ sub _diag {
 1;    # End of Test::MTA::Exim4
 
 __END__
+
 =pod
 
 =for test_synopsis 1;
 __END__
 
-=for stopwords acknowledgements mtas Maischein checkable exim exim4 recognised subitem subitems vapourware
+=for stopwords acknowledgements mtas Maischein checkable exim exim4 recognised subitem
+subitems vapourware CPAN behaviour homepage ok
 
 =head1 NAME
 
@@ -517,35 +649,41 @@ Test::MTA::Exim4 - Test Anything interface for testing Exim4 configurations
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
-L<Test::MTA::Exim4> allows the testing of an C<exim> installation
-and configuration using the perl TAP (Test Anything Protocol)
-methodology.
+L<Test::MTA::Exim4> allows the testing of an C<exim> installation and
+configuration using the perl TAP (Test Anything Protocol) methodology.
 
 This allows the writing of some simple test scripts which can check for
-features of C<exim> and check that this configuration routes, accepts
-or rejects mail as you would expect. As such it is an ideal system for
-creating a test suite for your mail configuration allowing you to check
-that there are no unexpected regressions when you make a change.
+features of C<exim> and check that this configuration routes, accepts or
+rejects mail as you would expect. As such it is an ideal system for creating a
+test suite for your mail configuration allowing you to check that there are no
+unexpected regressions when you make a change.
 
-You need to be aware that an C<exim> installation depends on more than
-just a config file - the exim binary, and the installation environment
-may effect the behaviour and/or routing of messages. You really need to
-do final configuration tests on the box that the system will be running
-on in production.
+You need to be aware that an C<exim> installation depends on more than just a
+config file - the exim binary, and the installation environment may effect the
+behaviour and/or routing of messages. You really need to do final configuration
+tests on the box that the system will be running on in production.
 
 =head1 WARNING
 
-At present this module is experimental - both the API and
-implementation are subject to change. To this end I welcome discussion
-on how best to implement or expose functionality. There is other work
-proposed to produce similar test modules for other MTAs and so a common
-mechanism or compatibility layer between them is possible - this module
-has been produced to get something out as code is a better discussion
-point than vapourware ideas!
+At present this module is experimental - both the API and implementation are
+subject to change. To this end I welcome discussion on how best to implement or
+expose functionality. There is other work proposed to produce similar test
+modules for other MTAs and so a common mechanism or compatibility layer between
+them is possible - this module has been produced to get something out as code
+is a better discussion point than vapourware ideas!
+
+Having said all that, it has now been around for several years, without
+substantial changes, so it may be as well to accept the API to be as stable as
+that of exim itself...
+
+=head1 EXAMPLES
+
+The C<sample> directory contains an example used for testing the <exim.org>
+installation, and should hopefully act as a reasonable example configuration.
 
 =head1 METHODS
 
@@ -553,10 +691,47 @@ point than vapourware ideas!
 
     my $exim = Test::MTA::Exim4->new( \%fields );
 
-Create a new exim configuration testing object. You may pass
-configuration information in as a hash reference - this is the only
-point at which the locations of the exim binary and configuration file
-may be set.
+Create a new exim configuration testing object. You may pass configuration
+information in as a hash reference - this is the only point at which the
+locations of the exim binary and configuration file may be set.
+
+The options that can be passed in are:-
+
+=over 4
+
+=item * exim_path
+
+This is the path to the exim binary.  If this is not set, the default is taken
+as the first of the following:-
+
+=over 4
+
+=item * C<DEFAULT_EXIM_PATH> - environment variable
+
+=item * C<exim4> in the current path
+
+=item * C<exim> in the current path
+
+=item * C</usr/sbin/exim>
+
+=back
+
+=item * config_file
+
+The configuration file used.  If this is not set the value of the environment
+variable C<DEFAULT_EXIM_CONFIG_FILE> is used and if that is not set no config
+file is passed to the exim binary (meaning the default compiled into that is
+used).
+
+=item * test
+
+A test object - defaults to a new instance of L<Test::Builder>
+
+=item * timeout
+
+The timeout enforced on commands, in seconds.  Defaults to 5 seconds.
+
+=back
 
 =head2 reset
 
@@ -564,32 +739,71 @@ Resets the internal state.  Not sure when this might be useful!
 
 =head2 config_ok
 
-Checks that C<exim> considers the configuration file as syntactically
-valid. The config file must be specified when C<new> is called,
-otherwise the default is used.
+Checks that C<exim> considers the configuration file as syntactically valid.
+The config file must be specified when C<new> is called, otherwise the default
+is used.
 
 =head2 exim_version
 
-Returns the version of C<exim> seen when the configuration was checked.
-This is intended for use within your own tests for appropriate
-versions, for example:-
+Returns the version of C<exim> seen when the configuration was checked. This is
+intended for use within your own tests for appropriate versions, for example:-
 
     # ensure we are running exim 4.69 or later
     ok(($exim->exim_version gt '4.69'), 'Exim version check');
 
 =head2 exim_build
 
-Returns the build number of C<exim> seen when the configuration was
-checked. This is intended for use within your own tests for appropriate
-versions/builds.
+Returns the build number of C<exim> seen when the configuration was checked.
+This is intended for use within your own tests for appropriate versions/builds.
+
+=head2 has_option
+
+    $exim->has_option($option, $optional_msg)
+
+Checks whether the named C<exim> option exists.  This is taken from the list of
+options listed by C<exim -bP>
+
+=head2 has_not_option
+
+    $exim->has_not_option($option, $optional_msg)
+
+Precisely the opposite of L<has_option> with an opposite test - so fails if the
+option does exist.
+
+=head2 option_is
+
+    $exim->option_is($option, $value, $optional_msg)
+
+Checks the named C<exim> option has the appropriate value.  This is taken from
+the list of options listed by C<exim -bP>
+
+=head2 option_is_true
+
+    $exim->option_is_true($option, $optional_msg)
+
+Checks the named C<exim> option has a true value.  This is taken from the list
+of options listed by C<exim -bP>
+
+=head2 option_is_false
+
+    $exim->option_is_false($option, $optional_msg)
+
+Checks the named C<exim> option has a false value.  This is taken from the list
+of options listed by C<exim -bP>
+
+=head2 expansion_is
+
+    $exim->expansion_is($string, $value, $optional_msg)
+
+Checks the given C<exim> expansion string ends up with the appropriate value.
 
 =head2 has_capability
 
     $exim->has_capability($type, $what, $optional_msg)
     $exim->has_capability('lookup', 'lsearch', 'Has lsearch capability')
 
-Checks that C<exim> has the appropriate capability.  This is taken from
-the lists of capabilities listed by C<exim -bV>
+Checks that C<exim> has the appropriate capability.  This is taken from the
+lists of capabilities listed by C<exim -bV>
 
 The types of capability are:-
 
@@ -607,29 +821,28 @@ The types of capability are:-
 
 =back
 
-The items within a capability are processed to be lowercase
-alphanumeric only - so C<iconv> rather than C<iconv()> as output by
-exim. The subitems (for example C<maildir> is a subitem of
-C<appendfile>) are treated as separately checkable items.
+The items within a capability are processed to be lowercase alphanumeric only -
+so C<iconv> rather than C<iconv()> as output by exim. The subitems (for example
+C<maildir> is a subitem of C<appendfile>) are treated as separately checkable
+items.
 
-If the version of C<exim> being used has both built-in and dynamic
-lookups (or potentially in later versions multiple types of other
-capabilities), then these are merged into a single capability list.
+If the version of C<exim> being used has both built-in and dynamic lookups (or
+potentially in later versions multiple types of other capabilities), then these
+are merged into a single capability list.
 
 =head2 has_not_capability
 
-Precisely the opposite of L<has_capability> with an opposite test - so
-fails if this does exist.
+Precisely the opposite of L<has_capability> with an opposite test - so fails if
+this does exist.
 
 =head2 routes_ok
 
     $exim->routes_ok($address, $optional_msg);
     $exim->routes_ok('address@example.com', 'Checking routing');
 
-Checks that C<exim> with this configuration can route to the address
-given. Accepts any working address which may route to any number of
-final targets as long as there are no undeliverable addresses in the
-set.
+Checks that C<exim> with this configuration can route to the address given.
+Accepts any working address which may route to any number of final targets as
+long as there are no undeliverable addresses in the set.
 
 =head2 routes_as_ok
 
@@ -637,13 +850,13 @@ set.
     $exim->routes_as_ok('address@example.com',
         {transport => 'local_smtp}, 'Checking routing');
 
-Checks that C<exim> with this configuration routes to the address
-given with the appropriate target results.
+Checks that C<exim> with this configuration routes to the address given with
+the appropriate target results.
 
-The target is an arrayref of hashes (or as a special case a single
-hash), which matches against the addresses section of the result from
-L<_run_exim_bt>. Each address matches if all the elements given in the
-target hash match (so an empty hash will match anything).
+The target is an arrayref of hashes (or as a special case a single hash), which
+matches against the addresses section of the result from L<_run_exim_bt>. Each
+address matches if all the elements given in the target hash match (so an empty
+hash will match anything).
 
 See L<_run_exim_bt> for hash elements.
 
@@ -652,16 +865,15 @@ See L<_run_exim_bt> for hash elements.
     $exim->discards_ok($address, $optional_msg);
     $exim->discards_ok('discards@example.com', 'Checking discarding');
 
-Checks that C<exim> with this configuration will discard the given
-address.
+Checks that C<exim> with this configuration will discard the given address.
 
 =head2 undeliverable_ok
 
     $exim->undeliverable_ok($address, $optional_msg);
     $exim->undeliverable_ok('discards@example.com', 'Checking discarding');
 
-Checks that C<exim> with this configuration will consider the given
-address to be undeliverable.
+Checks that C<exim> with this configuration will consider the given address to
+be undeliverable.
 
 =head1 INTERNAL METHODS
 
@@ -669,33 +881,41 @@ These methods are not intended to be run by end users, but are exposed.
 
 =head2 _run_exim_command
 
-Runs an exim instance with the appropriate config file and
+Runs an exim instance with the appropriate configuration file and arguments.
+The configuration file is taken from the test object, the arguments are passed
+as arguments to this function.
 
 =head2 _run_exim_bv
 
-Runs C<exim -bV> with the appropriate configuration file, to check that
-the configuration file is valid. The output of the command is parsed
-and stashed and used to provide the functions to check versions numbers
-and capabilities.
+Runs C<exim -bV> with the appropriate configuration file, to check that the
+configuration file is valid. The output of the command is parsed and stashed
+and used to provide the functions to check versions numbers and capabilities.
+
+=head2 _run_exim_bp
+
+Runs C<exim -bP> with the appropriate configuration file, to cause Exim to
+display the value of all the main configuration options. The output of the
+command is parsed and stashed and used to provide the functions to check
+individual option values.
+
+=head2 _run_exim_be
+
+Runs C<exim -be>, with the appropriate configuration file, in expansion testing
+mode, to cause Exim to expand the specified string.
 
 =head2 _run_exim_bt
 
-Runs C<exim -bt> (address test mode) with the appropriate configuration
-file, to check how the single address passed routes. The output of the
-command is parsed and passed back in the results.
+Runs C<exim -bt> (address test mode) with the appropriate configuration file,
+to check how the single address passed routes. The output of the command is
+parsed and passed back in the results.
 
-The results structure is hash that looks like:-
-    {
-        all_ok        => # no invocation errors
-        deliverable   => # number of deliverable addresses
-        undeliverable => # number of undeliverable addresses
-        total         => # total number of addresses
-        addresses     => {}
-    }
+The results structure is hash that looks like:-     {         all_ok        =>
+# no invocation errors         deliverable   => # number of deliverable
+addresses         undeliverable => # number of undeliverable addresses        
+total         => # total number of addresses         addresses     => {}     }
 
-The C<addresses> part of the structure has one key for each resultant
-address, the value of which is another hash, which may contain the
-following items:-
+The C<addresses> part of the structure has one key for each resultant address,
+the value of which is another hash, which may contain the following items:-
 
 =over 4
 
@@ -705,13 +925,12 @@ True if the address routed OK, False otherwise.
 
 =item * discarded
 
-True if the address was discarded by the router, false or missing if
-not.
+True if the address was discarded by the router, false or missing if not.
 
 =item * data
 
-Scalar of lines picked out of exim output related to this address and
-not otherwise recognised.
+Scalar of lines picked out of exim output related to this address and not
+otherwise recognised.
 
 =item * router
 
@@ -727,9 +946,9 @@ The final destination address.
 
 =item * original
 
-The original address that was used within this transformation. This is
-actually an arrayref each containing an address as several
-transformations may take place.
+The original address that was used within this transformation. This is actually
+an arrayref each containing an address as several transformations may take
+place.
 
 =item * target
 
@@ -739,17 +958,17 @@ For a local transport, the delivery target.
 
 =head2 _diag
 
-Spits out some L<Test::Builder> diagnostics for the last run command.
-Used internally by some tests on failure. The output data is the last
-error seen by L<IPC::Cmd> and the complete output of the command.
+Spits out some L<Test::Builder> diagnostics for the last run command. Used
+internally by some tests on failure. The output data is the last error seen by
+L<IPC::Cmd> and the complete output of the command.
 
 =head1 ACKNOWLEDGEMENTS
 
-The module draws very strongly on the L<Test::Exim4::Routing> module by
-Max Maischein. It is structured differently, and is currently very
-experimental (meaning the API may change in a big way), so these
-changes were made as a new module in a name space that is intended for
-use by similar modules for other MTAs.
+The module draws very strongly on the L<Test::Exim4::Routing> module by Max
+Maischein. It is structured differently, and is currently very experimental
+(meaning the API may change in a big way), so these changes were made as a new
+module in a name space that is intended for use by similar modules for other
+MTAs.
 
 =head1 INSTALLATION
 
@@ -757,23 +976,16 @@ See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported.
-
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Test-MTA-Exim4>.
+You can make new bug reports, and view existing ones, through the
+web interface at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Test-MTA-Exim4>.
 
 =head1 AVAILABILITY
 
-The project homepage is L<http://search.cpan.org/dist/Test-MTA-Exim4>.
+The project homepage is L<https://metacpan.org/release/Test-MTA-Exim4>.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see L<http://search.cpan.org/dist/Test-MTA-Exim4/>.
-
-The development version lives at L<http://github.com/nigelm/Test-MTA-Exim4>
-and may be cloned from L<git://github.com/nigelm/Test-MTA-Exim4.git>.
-Instead of sending patches, please fork this project using the standard
-git and github infrastructure.
+site near you, or see L<https://metacpan.org/module/Test::MTA::Exim4/>.
 
 =head1 AUTHOR
 
@@ -781,10 +993,9 @@ Nigel Metheringham <nigelm@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Nigel Metheringham.
+This software is copyright (c) 2014 by Nigel Metheringham.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
